# Top-k Models

A python data tool that predicts that top k classes of a dataset, calculates the Top-k accuracy for different models and selects the best classifier.

A solar radiation project that uses this tool to predict the level of solar radiation based on variables such as temperature, pressure, etc. can be found on https://github.com/priscilla-chk/top_k_models/tree/master/example_projects

# Documentation

Documentation can be found on https://github.com/priscilla-chk/top_k_models/

# Installation

top_k_models can be installed directly from pip/pip3:
  
  * pip install top_k_models
  

# Dependencies
  
  * numpy, pandas, sklearn
